Exception: AffirmIt::BehavioralChallenge
- Inherits:
-
Exception
- Object
- Exception
- AffirmIt::BehavioralChallenge
- Defined in:
- lib/affirmit/esteem.rb
Overview
This is a raise-able class to denote circumstances in which the code being affirmed behaves in an unexpected way. This is typically the case with high-sprited or strong-willed code. It could be a problem, but we prefer to medicate where possible.