Exception: AffirmIt::DifferingOpinion
- Inherits:
-
BehavioralChallenge
- Object
- Exception
- BehavioralChallenge
- AffirmIt::DifferingOpinion
- Defined in:
- lib/affirmit/esteem.rb
Overview
Please note carefully that although this class derives eventually from Exception, it does so solely so that it can be raised as a noteworthy condition. It is not to be negatively construed as an error in any way.