Class: AffirmIt::RoseColoredClasses
- Inherits:
-
Object
- Object
- AffirmIt::RoseColoredClasses
- Defined in:
- lib/affirmit/rosecoloredglasses.rb
Overview
If you're feeling as if nothing can go wrong, then maybe your frame of reference should be RoseColoredGlasses!
Instance Method Summary collapse
Instance Method Details
#is_true(something) ⇒ Object
6 7 8 |
# File 'lib/affirmit/rosecoloredglasses.rb', line 6 def is_true(something) true end |